/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks;

import org.gradle.api.Project;
import org.gradle.internal.service.ServiceRegistry;

import javax.annotation.Nullable;

/**
 * A self-contained action to run as a node in the work graph. Can be included in the dependencies of a {@link TaskDependencyContainer}.
 */
public interface WorkNodeAction {
    /**
     * Returns the project which the action requires access to, if any.
     */
    @Nullable
    Project getProject();

    /**
     * Run the action, throwing any failure.
     */
    void run(ServiceRegistry registry);
}
